@@ -85,8 +85,10 @@ aggregatingFunction1 <-
             data <- parent.frame()
           }
           formula <- formularise(lazy_formula, parent.frame(2)) 
-          formula <- mosaicCore::mosaic_formula_q(formula, groups = groups, max.slots = 3) 
-          maggregate(formula, data = data, FUN = FUNCTION_TBD, na.rm = na.rm, ..., .multiple = output.multiple)
+          formula <- 
+            mosaicCore::mosaic_formula_q(formula, groups = !!rlang::enexpr(groups), max.slots = 3) 
+          maggregate(formula, data = data, FUN = FUNCTION_TBD, na.rm = na.rm, ..., 
+                     .multiple = output.multiple)
         },
       formula = 
         function(
@@ -102,7 +104,8 @@ aggregatingFunction1 <-
             data <- parent.frame()
           }
           if (! inherits(x, "formula")) stop("`x' must be a formula")
-          formula <- mosaicCore::mosaic_formula_q(x, groups = groups, max.slots = 3) 
+          formula <- 
+            mosaicCore::mosaic_formula_q(x, groups = !!rlang::enexpr(groups), max.slots = 3) 
           maggregate(formula, data = data, FUN = FUNCTION_TBD, ..., .multiple = output.multiple)
         },
       
@@ -115,7 +118,9 @@ aggregatingFunction1 <-
         {
           if (rlang::is_formula(x)) {
             if (is.null(data)) data <- environment(x)
-            formula <- mosaicCore::mosaic_formula_q(x, groups = groups, max.slots = 3) 
+            formula <- 
+              mosaicCore::mosaic_formula_q(x, groups = !!rlang::enexpr(groups), max.slots = 3) 
+            
             return(maggregate(formula, data = data, FUN = FUNCTION_TBD, ..., 
                               na.rm = na.rm,
                               .multiple = OUTPUT.MULTIPLE))
