@@ -2,5 +2,5 @@ context("ashplot()")
 ashplot( ~age | substance, groups = sex, data = HELPrct)
 
 testthat::test_that("Ashplots work", {
-  vdiffr::expect_doppelganger("ashplots1", ashplot( ~age | substance, groups = sex, data = HELPrct))
-})
\ No newline at end of file
+  wrapped_expect_doppelganger("ashplots1", ashplot( ~age | substance, groups = sex, data = HELPrct))
+})
