@@ -2,19 +2,19 @@ context("frequencypolygon")
 
 testthat::test_that("freqpolygon() examples are working",{
  
-  vdiffr::expect_doppelganger(
+  wrapped_expect_doppelganger(
     "FirstExample", 
     freqpolygon(~age | substance, data = HELPrct, v = 35))
   
-  vdiffr::expect_doppelganger(
+  wrapped_expect_doppelganger(
     "SecondExample", 
     freqpolygon(~age, data = HELPrct, labels = TRUE, type = 'count'))
   
-  vdiffr::expect_doppelganger(
+  wrapped_expect_doppelganger(
     "ThirdExample", 
     freqpolygon(~age | substance, data = HELPrct, groups = sex))
   
-  vdiffr::expect_doppelganger(
+  wrapped_expect_doppelganger(
     "FourthExample", 
     freqpolygon(~age | substance, data = HELPrct, groups = sex, ylim = c(0,0.11)))
-})
\ No newline at end of file
+})
