@@ -14,12 +14,12 @@ testthat::test_that("rfun works", {
     return(res)
   }
   
-  vdiffr::expect_doppelganger("rfun1", plotFun(f(u,v)~u&v,u=range(-5,5),v=range(-5,5)))
+  wrapped_expect_doppelganger("rfun1", plotFun(f(u,v)~u&v,u=range(-5,5),v=range(-5,5)))
   
   myfun <- rfun( ~ u & v, seed = 1959)
   g <- rpoly2( ~ x & y & z, seed = 1964)
   
-  vdiffr::expect_doppelganger("rfun2", plotFun(g(x,y,z=2)~x&y,xlim=range(-5,5),ylim=range(-5,5)))
+  wrapped_expect_doppelganger("rfun2", plotFun(g(x,y,z=2)~x&y,xlim=range(-5,5),ylim=range(-5,5)))
 })
 
 
